@@ -32,7 +32,7 @@ def update_menu():
 	if item != None:
 		for action in model:
 			regex = re.compile(action[0])
-			if regex.match(item) != None:
+			if regex.search(unicode(item)) != None:
 				for cmd in action.iterchildren():
 					item = gtk.MenuItem(cmd[3])
 					item.connect("activate", commandActivated, cmd[0])
